=========
Changelog
=========

Version 0.2.2
=============

- added GitHub PyPi upload on release action
- new orbit flags
- new metadata convention for advisory flags

Version 0.2.1
=============

- s1dc-flood-mapper updates (v1.0)

Version 0.2.0
=============

- updates for new tempinator version (v1.0)
- restructured "lib" folder structure
- adapted config file parsing

Version 0.1.5
=============

- corrected author e-mail address

Version 0.1.4
=============

- updates for new s1-sigma version 1.0

Version 0.1.3
=============

- added metadata definition for flood products

Version 0.1.2
=============

- added metadata definition for harmonic parameter products

Version 0.1.1
=============

- added metadata definition for temporal aggregated products

Version 0.1.0
=============

- setup of first basic metadata class
- supports encoding and decoding of attributes
- support for SAR product metadata
